@@ -136,7 +136,7 @@ class Client:
                 boolean: True if the operation was a success, false if otherwise
         '''
         now                         = datetime.datetime.utcnow()
-        patient_data['UPDATED_AT']  = str(now)
+        patient_data['UPDATED_AT']  = str(now).replace(' ','T')
         print(patient_data)
         patient_mrn                 = patient_data['MRN']
         patient_id                  = Helpers.patient_hash(self.client_uuid, [patient_mrn])[0]
